@@ -1,14 +1,14 @@
 #  You may distribute under the terms of either the GNU General Public License
 #  or the Artistic License (the same terms as Perl itself)
 #
-#  (C) Paul Evans, 2008-2014 -- leonerd@leonerd.org.uk
+#  (C) Paul Evans, 2008-2017 -- leonerd@leonerd.org.uk
 
 package String::Tagged;
 
 use strict;
 use warnings;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Scalar::Util qw( blessed );
 
@@ -123,7 +123,9 @@ Out-of-band data
 
 =cut
 
-=head2 $st = String::Tagged->new( $str )
+=head2 new
+
+   $st = String::Tagged->new( $str )
 
 Returns a new instance of a C<String::Tagged> object. It will contain no tags.
 If the optional C<$str> argument is supplied, the string buffer will be
@@ -149,7 +151,9 @@ sub new
    }, $class;
 }
 
-=head2 $st = String::Tagged->new_tagged( $str, %tags )
+=head2 new_tagged
+
+   $st = String::Tagged->new_tagged( $str, %tags )
 
 Shortcut for creating a new C<String::Tagged> object with the given tags
 applied to the entire length. The tags will not be anchored at either end.
@@ -169,7 +173,9 @@ sub new_tagged
    return $self;
 }
 
-=head2 $new = String::Tagged->clone( $orig, %opts )
+=head2 clone (class)
+
+   $new = String::Tagged->clone( $orig, %opts )
 
 Returns a new instance of C<String::Tagged> made by cloning the original,
 subject to the options provided. The returned instance will be in the
@@ -206,7 +212,9 @@ applied with its existing value.
 
 =back
 
-=head2 $new = $orig->clone( %args )
+=head2 clone (instance)
+
+   $new = $orig->clone( %args )
 
 Called as an instance (rather than a class) method, the newly-cloned instance
 is returned in the same class as the original.
@@ -273,9 +281,11 @@ sub _mkextent
 
 =cut
 
-=head2 $str = $st->str
+=head2 str
 
-=head2 "$st"
+   $str = $st->str
+
+   $str = "$st"
 
 Returns the plain string contained within the object.
 
@@ -295,9 +305,11 @@ sub str
    return $self->{str};
 }
 
-=head2 $len = $st->length
+=head2 length
 
-=head2 $len = length( $st )
+   $len = $st->length
+
+   $len = length( $st )
 
 Returns the length of the plain string. Because stringification works on this
 object class, the normal core C<length> function works correctly on it.
@@ -310,7 +322,9 @@ sub length
    return CORE::length $self->{str};
 }
 
-=head2 $str = $st->substr( $start, $len )
+=head2 substr
+
+   $str = $st->substr( $start, $len )
 
 Returns a C<String::Tagged> instance representing a section from within the
 given string, containing all the same tags at the same conceptual positions.
@@ -346,7 +360,9 @@ sub substr
    return $ret;
 }
 
-=head2 $str = $st->plain_substr( $start, $len )
+=head2 plain_substr
+
+   $str = $st->plain_substr( $start, $len )
 
 Returns as a plain perl string, the substring at the given position. This will
 be the same string data as returned by C<substr>, only as a plain string
@@ -417,7 +433,7 @@ sub _insert_tag
    # Two more special cases - it's quite likely we're either inserting an
    # 'everywhere' tag, or appending one to the end. Check the endpoints first
    local $b;
-   
+
    $b = $tags->[0];
    if( _cmp_tags() <= 0 ) {
       unshift @$tags, $newtag;
@@ -468,7 +484,9 @@ sub _insert_tag
    $self->_assert_sorted if DEBUG;
 }
 
-=head2 $st->apply_tag( $start, $len, $name, $value )
+=head2 apply_tag
+
+   $st->apply_tag( $start, $len, $name, $value )
 
 Apply the named tag value to the given extent. The tag will start on the
 character at the C<$start> index, and continue for the next C<$len>
@@ -484,7 +502,7 @@ string, will continue to the end even if more text is appended.
 
 This method returns the C<$st> object.
 
-=head2 $st->apply_tag( $e, $name, $value )
+   $st->apply_tag( $e, $name, $value )
 
 Alternatively, an existing extent object can be passed as the first argument
 instead of two integers. The new tag will apply at the given extent.
@@ -587,14 +605,16 @@ sub _remove_tag
    return $self;
 }
 
-=head2 $st->unapply_tag( $start, $len, $name )
+=head2 unapply_tag
+
+   $st->unapply_tag( $start, $len, $name )
 
 Unapply the named tag value from the given extent. If the tag extends beyond
 this extent, then any partial fragment of the tag will be left in the string.
 
 This method returns the C<$st> object.
 
-=head2 $st->unapply_tag( $e, $name )
+   $st->unapply_tag( $e, $name )
 
 Alternatively, an existing extent object can be passed as the first argument
 instead of two integers.
@@ -607,14 +627,16 @@ sub unapply_tag
    return $self->_remove_tag( 1, @_ );
 }
 
-=head2 $st->delete_tag( $start, $len, $name )
+=head2 delete_tag
+
+   $st->delete_tag( $start, $len, $name )
 
 Delete the named tag within the given extent. Entire tags are removed, even if
 they extend beyond this extent.
 
 This method returns the C<$st> object.
 
-=head2 $st->delete_tag( $e, $name )
+   $st->delete_tag( $e, $name )
 
 Alternatively, an existing extent object can be passed as the first argument
 instead of two integers.
@@ -627,7 +649,9 @@ sub delete_tag
    return $self->_remove_tag( 0, @_ );
 }
 
-=head2 $st->merge_tags( $eqsub )
+=head2 merge_tags
+
+   $st->merge_tags( $eqsub )
 
 Merge neighbouring or overlapping tags of the same name and equal values.
 
@@ -691,7 +715,9 @@ sub merge_tags
    }
 }
 
-=head2 $st->iter_extents( $callback, %opts )
+=head2 iter_extents
+
+   $st->iter_extents( $callback, %opts )
 
 Iterate the tags stored in the string. For each tag, the CODE reference in
 C<$callback> is invoked once, being passed an extent object that represents
@@ -762,7 +788,9 @@ sub iter_extents
    }
 }
 
-=head2 $st->iter_tags( $callback, %opts )
+=head2 iter_tags
+
+   $st->iter_tags( $callback, %opts )
 
 Iterate the tags stored in the string. For each tag, the CODE reference in
 C<$callback> is invoked once, being passed the start point and length of the
@@ -788,7 +816,9 @@ sub iter_tags
    );
 }
 
-=head2 $st->iter_extents_nooverlap( $callback, %opts )
+=head2 iter_extents_nooverlap
+
+   $st->iter_extents_nooverlap( $callback, %opts )
 
 Iterate non-overlapping extents of tags stored in the string. The CODE
 reference in C<$callback> is invoked for each extent in the string where no
@@ -889,7 +919,9 @@ sub iter_extents_nooverlap
    }
 }
 
-=head2 $st->iter_tags_nooverlap( $callback, %opts )
+=head2 iter_tags_nooverlap
+
+   $st->iter_tags_nooverlap( $callback, %opts )
 
 Iterate extents of the string using C<iter_extents_nooverlap>, but passing
 the start and length of each extent to the callback instead of the extent
@@ -916,7 +948,9 @@ sub iter_tags_nooverlap
    );
 }
 
-=head2 $st->iter_substr_nooverlap( $callback, %opts )
+=head2 iter_substr_nooverlap
+
+   $st->iter_substr_nooverlap( $callback, %opts )
 
 Iterate extents of the string using C<iter_extents_nooverlap>, but passing the
 substring of data instead of the extent object.
@@ -942,7 +976,9 @@ sub iter_substr_nooverlap
    );
 }
 
-=head2 @names = $st->tagnames
+=head2 tagnames
+
+   @names = $st->tagnames
 
 Returns the set of tag names used in the string, in no particular order.
 
@@ -962,7 +998,9 @@ sub tagnames
    keys %tags;
 }
 
-=head2 $tags = $st->get_tags_at( $pos )
+=head2 get_tags_at
+
+   $tags = $st->get_tags_at( $pos )
 
 Returns a HASH reference of all the tag values active at the given position.
 
@@ -990,7 +1028,9 @@ sub get_tags_at
    return \%tags;
 }
 
-=head2 $value = $st->get_tag_at( $pos, $name )
+=head2 get_tag_at
+
+   $value = $st->get_tag_at( $pos, $name )
 
 Returns the value of the named tag at the given position, or C<undef> if the
 tag is not applied there.
@@ -1018,7 +1058,9 @@ sub get_tag_at
    return $value;
 }
 
-=head2 $extent = $st->get_tag_extent( $pos, $name )
+=head2 get_tag_extent
+
+   $extent = $st->get_tag_extent( $pos, $name )
 
 If the named tag applies to the given position, returns the extent of the tag
 at that position. If it does not, C<undef> is returned. If an extent is
@@ -1057,7 +1099,9 @@ sub get_tag_extent
    }
 }
 
-=head2 $extent = $st->get_tag_missing_extent( $pos, $name )
+=head2 get_tag_missing_extent
+
+   $extent = $st->get_tag_missing_extent( $pos, $name )
 
 If the named tag does not apply at the given position, returns the extent of
 the string around that position that does not have the tag. If it does exist,
@@ -1095,7 +1139,9 @@ sub get_tag_missing_extent
    return $self->_mkextent( $start, $self->length, 0 );
 }
 
-=head2 $st->set_substr( $start, $len, $newstr )
+=head2 set_substr
+
+   $st->set_substr( $start, $len, $newstr )
 
 Modifies a extent of the underlying plain string to that given. The extents of
 tags in the string are adjusted to cope with the modified region, and the
@@ -1243,7 +1289,9 @@ sub set_substr
    return $self;
 }
 
-=head2 $st->insert( $start, $newstr )
+=head2 insert
+
+   $st->insert( $start, $newstr )
 
 Insert the given string at the given position. A shortcut around
 C<set_substr>.
@@ -1261,9 +1309,11 @@ sub insert
    $self->set_substr( $at, 0, $new );
 }
 
-=head2 $st->append( $newstr )
+=head2 append
 
-=head2 $st .= $newstr
+   $st->append( $newstr )
+
+   $st .= $newstr
 
 Append to the underlying plain string. A shortcut around C<set_substr>.
 
@@ -1300,7 +1350,9 @@ sub append
    return $self;
 }
 
-=head2 $st->append_tagged( $newstr, %tags )
+=head2 append_tagged
+
+   $st->append_tagged( $newstr, %tags )
 
 Append to the underlying plain string, and apply the given tags to the
 newly-inserted extent.
@@ -1323,9 +1375,11 @@ sub append_tagged
    return $self;
 }
 
-=head2 $ret = $st->concat( $other )
+=head2 concat
 
-=head2 $ret = $st . $other
+   $ret = $st->concat( $other )
+
+   $ret = $st . $other
 
 Returns a new C<String::Tagged> containing the two strings concatenated
 together, preserving any tags present. This method overloads normal string
@@ -1355,7 +1409,9 @@ sub concat
    return $ret->append( $other );
 }
 
-=head2 @subs = $st->matches( $regexp )
+=head2 matches
+
+   @subs = $st->matches( $regexp )
 
 Returns a list of substrings (as C<String::Tagged> instances) for every
 non-overlapping match of the given C<$regexp>.
@@ -1398,7 +1454,9 @@ sub matches
    return @ret;
 }
 
-=head2 @parts = $st->split( $regexp, $limit )
+=head2 split
+
+   @parts = $st->split( $regexp, $limit )
 
 Returns a list of substrings by applying the regexp to the string content;
 similar to the core perl C<split> function. If C<$limit> is supplied, the
@@ -1434,7 +1492,9 @@ sub split
    return @ret;
 }
 
-=head2 $ret = $st->debug_sprintf
+=head2 debug_sprintf
+
+   $ret = $st->debug_sprintf
 
 Returns a representation of the string data and all the tags, suitable for
 debug printing or other similar use. This is a format such as is given in the
